var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
[
    [ "ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a549bd90e8cdb71762a48aec59a313dd3", null ],
    [ "ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7afb32f0574cb707876c4502680dfd80", null ],
    [ "~ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a485495727d37abd66295bab95d368438", null ],
    [ "addExtraSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7a402c710af1af5fabf7505848dad047", null ],
    [ "allocateEMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4e78c033b2c8c038038887105d67b115", null ],
    [ "allocateRotatedSHMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa978d98f77a64fb16862b67a0de634be", null ],
    [ "allocateRRPMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4f8698493efda1aa3e057c266d5c697b", null ],
    [ "allocateSO3CoeffsSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abc4a61da919ae37b0a03d23df2461224", null ],
    [ "allocateWignerMatricesSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aea644c87703e005507e187aa0ffa64b7", null ],
    [ "centreMapOnCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a80ff45ef40549fb6a1d80b70865fc807", null ],
    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2b60ba4e2dd8ef4918b6f0ea5316a009", null ],
    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a60643383ab239888adeee6e757876c80", null ],
    [ "computeOptimalTranslation", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a68ac89c84a5e67582d050218566d9a44", null ],
    [ "computePdbRotationCentre", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa48fc72e389e663248d27eedbbf32314", null ],
    [ "computeRotatedSH", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad39f33c52f6d4f0db8e0d63ed0c9a2f3", null ],
    [ "computeRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac7cb89ed871668c57a3b5dc953c20482", null ],
    [ "computeRRPMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6db2dcf87a6f763909ab08201e8de550", null ],
    [ "computeSphericalHarmonics", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a23f9a5f8f6fb7cf0f0324bc1d83d6090", null ],
    [ "computeTranslationMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a767640acbf4999201ce9ea86d76ff6a1", null ],
    [ "convertRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad96cd7a72fc56e7d97cfeff1086faad9", null ],
    [ "createNewMapFromBounds", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3349a7f6ffecc3ffd4e09192eb919248", null ],
    [ "deepCopyMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac3fbad5b8628112ace798950e6068bd4", null ],
    [ "detectSymmetryFromAngleAxisSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abcf770f9177a4d2f1a94a3adb20bf790", null ],
    [ "detectSymmetryInStructure", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afac05cfadc141435c4fc4a568ecffe29", null ],
    [ "figureIndexStartStop", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a476092aa08dff20d64a895e7b2227b2e", null ],
    [ "findMapCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac07955296611dd411cf5ed87ced90571", null ],
    [ "findRequestedCSymmetryFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2714fcb2c08b224ccf09d64322bd2ab2", null ],
    [ "findTopGroupSmooth", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a671ebb0985408bff451ec359b4df79b9", null ],
    [ "getAllGroupElements", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae2f2469c7d252c5e87d7bf9976b9b796", null ],
    [ "getAnySphereRadius", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a23620b34a604aca7db4d8b21f6d2d09a", null ],
    [ "getBestRotationMapPeaksEulerAngles", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a129f0b665c31fe2d6c7a03f1ba9997de", null ],
    [ "getBestTranslationMapPeaksAngstrom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7955b0afcc99b569aba1023210e23e81", null ],
    [ "getComparisonBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6cc2b8e179a137adda234e0ba0f9d27b", null ],
    [ "getCyclicSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a421d8cf46b6671857d0054cf0defe17f", null ],
    [ "getCyclicSymmetriesListFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afa3b1a8ef870a606035102b5dcf1ce44", null ],
    [ "getDihedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a1fdc5b9df47ff8de3a5f2f6e6ce233a5", null ],
    [ "getEMatrixByBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a94a73f81ba80621f5f52173e91bb47f7", null ],
    [ "getEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab053362f9dc5422244ccfbafd9f00ff8", null ],
    [ "getIcosahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad46b5c9a39df4faa45cc53d31aab43db", null ],
    [ "getImagEMatrixValuesForLM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9b08a8b6f9569c06cd183c924e6e80de", null ],
    [ "getImagRotFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9b063d1ca2ebed239029bad6250cf376", null ],
    [ "getImagSO3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4b76352faa0915b1fef943fe139de5a6", null ],
    [ "getImagSphHarmValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aae8444b6c9ca3207d32bbf2a68c7b610", null ],
    [ "getImagTranslationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a97766b6a74aee4c364c1fd8efd6478ff", null ],
    [ "getIntegrationWeight", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa150cfc5715420cf3d2e28c8af3631c4", null ],
    [ "getInternalMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a1bb8bf1e357cc25f68fe93554e44715d", null ],
    [ "getInvSO3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2eb10989a2f8d46b849cdaf8410b68be", null ],
    [ "getMapCOMProcessChange", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4bd7a9a5ea6cac4302ec1cd80922c617", null ],
    [ "getMapValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afe04510c67e9dc9c19efaef8463b6e6e", null ],
    [ "getMaxBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a152b43815a3d3debd4b60751d9c8afdd", null ],
    [ "getMaxSpheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2245b15f279de574406204156089e5ef", null ],
    [ "getNoRecommendedSymmetryAxes", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad1fdcd9bdebc2900748821c5b3cb53cc", null ],
    [ "getOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a14c4d6044c5174afa8a0984025c45436", null ],
    [ "getOverlayRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad409e4556676857224d1f5e00e5b7911", null ],
    [ "getPredictedIcosahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad9a02d8d68aac021572b764651aad0f1", null ],
    [ "getPredictedOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae97b54a34689c1dceae47a5e8e94bbb0", null ],
    [ "getPredictedTetrahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a931aa4c10c426c3b8041bd4e838b0678", null ],
    [ "getRealEMatrixValuesForLM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa757f9d32ebe20435661599652fd30fa", null ],
    [ "getRealRotFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8bc5fbad1079d42bfa73913a9e2df619", null ],
    [ "getRealSO3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a30eac0ab5b69c1b7190d6e56571ba8b8", null ],
    [ "getRealSphHarmValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5c0df68cd21b4f56abd1008065ca3573", null ],
    [ "getRealTranslationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a94cce09895dc9f41d4b9a429ccf638e8", null ],
    [ "getReBoxBoundaries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac0dc9f3ed79cc98719e6b727bb8bb982", null ],
    [ "getRecommendedSymmetryFold", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8e1bd5bd5a3fd12691a1d83735c13250", null ],
    [ "getRecommendedSymmetryType", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad5add825ce8d5e5d9f598f6912f07aff", null ],
    [ "getRotMatrixFromRotFunInds", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a688bac56d3c483bd99c0ff7d63cf7602", null ],
    [ "getRRPValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afa35ae5ccd9d4b22bcc028f609cd1c3e", null ],
    [ "getShellBandwidth", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a898b48c1135e7a37f64f55e2367f0391", null ],
    [ "getSO3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae5c9c45b0db1e6a9eeef2ba292fbbcc3", null ],
    [ "getSpherePositions", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a188b648a0ad28b598d682ca14f288dc4", null ],
    [ "getSpherePosValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a38d47eb11eafa106c65867ceec62a3fc", null ],
    [ "getSymmetryAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0662f17e733fb6c1a16f04b273f8b7a5", null ],
    [ "getTetrahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a85bfab9b1babe0b35e6d81f525ead29b", null ],
    [ "getTranslationFnPointer", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae27a3e92905ca9d5f9a32c4eaacc64ae", null ],
    [ "getWignerMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5999f7181bd3509454966f8271ac39d6", null ],
    [ "getXAxisOrigin", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8a1405b3974697f41c4a73da0cb52a32", null ],
    [ "getXDim", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3bc44913222e67ab861dd1e5838c1ae1", null ],
    [ "getXDimSize", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a51d7b9d87d536ef0c48d820872bc9185", null ],
    [ "getXFromPtr", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4c89c860da1836b30a9b2889d3e873ed", null ],
    [ "getXToPtr", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#adf61c328db45fcd7692d13a8cde5e092", null ],
    [ "getYAxisOrigin", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a298bc9a6aae624a091cd97b842a6b618", null ],
    [ "getYDim", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a50c884973add562558803a45991bbf19", null ],
    [ "getYDimSize", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae477e3c0d7b866e6069d8603950afe51", null ],
    [ "getYFromPtr", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5f0d929d1e013cdd23e956d94b7a40da", null ],
    [ "getYToPtr", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac859cbd21b93b9d2ed5f119f4ee57f3f", null ],
    [ "getZAxisOrigin", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aeb0242051835b508e9af193dc40a697c", null ],
    [ "getZDim", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a034af93b9152fb2db675d5632a4ebc6d", null ],
    [ "getZDimSize", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#af4d641d62864e4adf67c1365b0960970", null ],
    [ "getZFromPtr", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afbbcec01a6ee7701e3b1d0e61730fadf", null ],
    [ "getZToPtr", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a68eb739dd4846a1dd48032eb2cc3f49c", null ],
    [ "interpolateMapFromSpheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9d11953ff54d5774659117be22bdb3b3", null ],
    [ "invertMirrorMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa67115a6b234764c958899863fb60b54", null ],
    [ "invertSHCoefficients", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac3dbae1c18d0550ee1940cadb5335684", null ],
    [ "mapToSpheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a56bfcfacedabd84ec54aa2843d59e014", null ],
    [ "maskMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0122be830893f5d82bab742be54d1ee7", null ],
    [ "normaliseEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aceb19c915cebcef22c085cc6619cc472", null ],
    [ "normaliseMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a255bdb77824ce0fddc2454d5823219e1", null ],
    [ "prepareFSCFourierMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a51b1eb3cb274c1c68e85cf3cca0c25b7", null ],
    [ "processInternalMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afcb4202e9ffea1b99c59f73faf06d899", null ],
    [ "readInMAP", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a07fb6e354dcd90dc70f8b4fa8bba0c33", null ],
    [ "readInPDB", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abd1c1b3588308f775da5c8aeba3f3e78", null ],
    [ "readInStructure", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a59f2f2ce1bfdb90432c5a29600fdd9e6", null ],
    [ "removePhaseInormation", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5919acc2f26efcf373db47ed96eadc38", null ],
    [ "reportOverlayResults", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a43e3cad6f93a32f92194f76f0ec76a32", null ],
    [ "reportSymmetryResults", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abea2d62360b17cddca155816d3e485e8", null ],
    [ "reSampleMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab573ea90a16991a06a77c5343328b060", null ],
    [ "rotateMapRealSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7c7b69293bb883a84cde8031bb217f0a", null ],
    [ "rotateMapRealSpaceInPlace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8c4f14e31f4ad0f08d4558b732ef4b8c", null ],
    [ "rotateMapReciprocalSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa12ba3d9d61e240ec2d91d924e6cb0d3", null ],
    [ "saveDetectedSymmetries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0b0608e80f20087b24cc9498767f0894", null ],
    [ "saveRecommendedSymmetry", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a262b3b0e1129d4d3a5830a8982395f01", null ],
    [ "saveRequestedSymmetryC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a599a8fa1d6d780a45a2d772413bc778e", null ],
    [ "saveRequestedSymmetryD", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a51fec3f0a115640181f6e7ce102e4b37", null ],
    [ "setEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aca5af5c8c3b18275e65ae4ebacd9877c", null ],
    [ "setIntegrationWeight", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3e7b1d5d4164ea7a6fda53c57ac979f4", null ],
    [ "setIntegrationWeightCumul", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a737ee01d968fef7ae1094847a0271033", null ],
    [ "setPDBMapValues", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a30edd2928e423198704adb955989960b", null ],
    [ "setSO3CoeffValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aca5e27540622190be41ce78157c0807e", null ],
    [ "setWignerMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab3aa4cdcd7cc9b458d7618077dfaab02", null ],
    [ "shellBandExists", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ada8e6f27f49afc3a0ee17758ce9e7594", null ],
    [ "so3CoeffsArrayIndex", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9f6ba75b25e201466929bfd4df75688d", null ],
    [ "translateMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7170576d4823143e7dd270e0f202d0b4", null ],
    [ "writeMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a81e6aab30488052e6bdd9b339e8124d8", null ],
    [ "writeMask", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aac87b1a87f32a742ea2b41014dac5f7b", null ],
    [ "writeOutOverlayFiles", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6160812636f73e33c1c46a754b68a610", null ],
    [ "writePdb", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0322fb97dcd3c0495f98963210f36c27", null ],
    [ "zeroPaddToDims", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0cdec5190d4b2ae60350f0f6db751d4b", null ],
    [ "aAngle", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa75beee618649d6fd9dc850a5a66a551", null ],
    [ "bAngle", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9dbcec9f32eb76625d7aa59d8c2701d9", null ],
    [ "cAngle", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8e2f99f00dd05198b508633cf7f6f080", null ],
    [ "eMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a82b2d8f8c05da2eccb5561e6455b4d44", null ],
    [ "fileName", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae9b0d5959b0f461b3b89ffeb059400fa", null ],
    [ "fileType", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4052e498b4650f62bfe5ff37ed959292", null ],
    [ "inputOrder", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a99ab4a34f3a42c17f923ef131c64b4a7", null ],
    [ "integrationWeight", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5d266289b137b48132f1456fd8fc43ea", null ],
    [ "internalMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8aa6fbd67df9911e886f9001a0ef8bc2", null ],
    [ "isEmpty", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac57d606fdb59d54bd3f9249941402b12", null ],
    [ "mapCOMProcessChangeX", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a471ec29b27c3a402d18b20fee8035f1a", null ],
    [ "mapCOMProcessChangeY", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a47bf2343b0b50267e8e3732c964b63ea", null ],
    [ "mapCOMProcessChangeZ", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a487131ae5dc44f8667908bf64725b4ab", null ],
    [ "mapMovFromsChangeX", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7861a96d94b8f7a8eb2946729c330863", null ],
    [ "mapMovFromsChangeY", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a1658311301e365cf17721e864b829c28", null ],
    [ "mapMovFromsChangeZ", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a682749f30d2fd19842d96e9b870d76ab", null ],
    [ "maxCompBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a99ed9b0a765739d89104eca2c1875dd4", null ],
    [ "maxShellBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a367d0cd13e3d7a2648488980220ca69b", null ],
    [ "noSpheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a411b398b06557387320b56c6b8233fc4", null ],
    [ "originalMapXCom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2a3fdf194eca61b1ccfa5bdd2f586e0b", null ],
    [ "originalMapYCom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a64323b4117a11f0971cb0d24ec95c64c", null ],
    [ "originalMapZCom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac00197ab71e3353cb2884be0e51d6cd3", null ],
    [ "originalPdbRotCenX", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a923cdc6e27455ba99ce5f536932f3721", null ],
    [ "originalPdbRotCenY", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a77cabdd70039e82f8c0cbb07fefd3960", null ],
    [ "originalPdbRotCenZ", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a924d0767561842716b2ac260426cdc19", null ],
    [ "originalPdbTransX", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9548e8ff07c6a74bbe2353f647fb6a79", null ],
    [ "originalPdbTransY", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5241ee8b8b9d9915e1ef92e3edab202d", null ],
    [ "originalPdbTransZ", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aee571cb10ce61ab11680b1ebd5e23eb7", null ],
    [ "rotSphericalHarmonics", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a94b04108aa1a9406eb3c5eb61749140b", null ],
    [ "rrpMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#af8b72cbc56a4f72d0557e01a8101d435", null ],
    [ "so3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad5416490eb3eba7539d08a5b324fbadb", null ],
    [ "so3CoeffsInverse", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a33312dd4333617b460628e4db4bf41fc", null ],
    [ "sphereMappedRotFun", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a50358df39a25e9ba02fe2794d4a2ca28", null ],
    [ "spherePos", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a31b57e51f48e58828883b04b612dcf55", null ],
    [ "spheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa414664dde18320cc52075640590d51d", null ],
    [ "sphericalHarmonics", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5f934f331c4d3bc7c0a6f63486b2f90e", null ],
    [ "translationMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a37f26ac4bc76e4f4c5da77dd0eace56e", null ],
    [ "wignerMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a618fc0fc9ca71ec70500c99c7e6231f4", null ],
    [ "xAxisOrder", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a603841095e16abd0492dfc6db052fda7", null ],
    [ "xAxisOrigin", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2860d3acb4d9e5ec6fca0b58ae33845f", null ],
    [ "xAxisOriginOriginal", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a43f1c4682016759ea2e24c5903dbe444", null ],
    [ "xCom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a59fbe922fd7fd7aa5c72ca459e4242d0", null ],
    [ "xDimIndices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aceb7facd99379a000035ce35263577d5", null ],
    [ "xDimIndicesOriginal", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9598e9a38546e3bf260bc09c0c9366a2", null ],
    [ "xDimSize", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aff65990df92e49b7636134feb56be8f9", null ],
    [ "xDimSizeOriginal", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a1ae6821c27e7facf63839c9fc678c9c7", null ],
    [ "xFrom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afef6a064a54eb016776cb0879efb0b31", null ],
    [ "xGridIndices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aedb2ba02e77d5795077df91b2578ab29", null ],
    [ "xTo", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac40e8210bd69b598a67c6a3e0a9ecf16", null ],
    [ "yAxisOrder", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9302095b8642b8d5088cf8f1793d1990", null ],
    [ "yAxisOrigin", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3e2a50d383cdba4b6f6f3d1293c4174b", null ],
    [ "yAxisOriginOriginal", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a53cffdab0d66cb88884ec4f46c19a5ff", null ],
    [ "yCom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a668381d94a927275b3d839549475c7da", null ],
    [ "yDimIndices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab4da4e87f23a07702dcf32470ec740df", null ],
    [ "yDimIndicesOriginal", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a1ef18126c2c24edc9b6be06e0591127f", null ],
    [ "yDimSize", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a37b2746ce3f6560446b4eb45ba552084", null ],
    [ "yDimSizeOriginal", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7855424ca5d51853c7fc665ecb9b935b", null ],
    [ "yFrom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5d47aafdd2ec9912225c3c44e2bbc4d8", null ],
    [ "yGridIndices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3d56e4edf14f91833ddfe8908887b506", null ],
    [ "yTo", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a47b4953dae84a5ab54dadd33d7805887", null ],
    [ "zAxisOrder", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a550c839b5ce7b53ccee5e6da1cf001af", null ],
    [ "zAxisOrigin", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a57a45df67d87117582f0810ca9f48695", null ],
    [ "zAxisOriginOriginal", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aed1c8e0ffb847b093a736c5156f86e9b", null ],
    [ "zCom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a668c168ea0037312025b860b9b5be415", null ],
    [ "zDimIndices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad1f180d58f829e2c0fc50569b2425d56", null ],
    [ "zDimIndicesOriginal", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a1ea6522b99cf1ac72199c9eeccd30742", null ],
    [ "zDimSize", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a20fd31138680dd622058732eba31dca5", null ],
    [ "zDimSizeOriginal", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a530ad7e3396cbcbc1814051031070a8b", null ],
    [ "zFrom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a14980cdf619bcda026b9aad282c2064b", null ],
    [ "zGridIndices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a67d6eadd10e10c0b46f1f2e43df7db99", null ],
    [ "zTo", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a930e25e9377cf418f6eab71fa2837255", null ]
];